;; Generated package description from dired-preview.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "dired-preview" "0.6.0.0.20260111.184511" "Automatically preview file at point in Dired" '((emacs "28.1")) :commit "b0cba0825d2eea2ac6d9a8ef65a73b6186e6d294" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("files" "convenience") :url "https://github.com/protesilaos/dired-preview")
